# Long-term strategic infrastructure planning model for Saint Lucia

This Excel model encodes the analytical capability required to undertake an
application of the unique and pioneering National Infrastructure Systems
Modelling (NISMOD) capability, which has been developed by the Infrastructure
Transitions Research Consortium (ITRC)- a UK based research consortium, led by
the University of Oxford. Through a partnership between the United Nations
Office for Project Service (UNOPS) and the ITRC, an initial national
infrastructure assessment for Saint Lucia – a first-of-its-kind for the country,
has been performed. Find further details in the [St Lucia National
Infrastructure
Assessment](https://content.unops.org/publications/Saint-Lucia-National-Infrastructure-Assessment.pdf)
(Adshead et al, 2020).

This model was designed to provide useful insights into the cross-sectoral
performance of Saint Lucia's infrastructure systems. This includes, with respect
to:

- A) the structure and function of current infrastructure systems
- B) the characterization of future infrastructure needs by developing scenarios of the future
- C) the development of a future infrastructure-related vision for Saint Lucia
- D) the  identification of strategic alternatives to meet future needs
- E) analysis of the performance of strategic alternatives
- F) the assembly of adaptive pathways of infrastructure investments and policies

Data on the current infrastructure (A) has been collected mostly from public
sources. Currently, the model uses the most recently available data and has been
designed in a way that allows users to change and update key data inputs. These
data inputs are highlighted in red throughout the model.

The main drivers of infrastructure demand (B) for Saint Lucia were identified.
These include: the residential population; future tourism numbers and climate
change . By integrating multiple forecasts, three future scenarios were
developed to provide a consistent set of demand drivers, across sectors, that
determine the scope of future needs for Saint Lucia’s infrastructure systems.
This analysis reveals the broad range of uncertainty that should be considered
in planning future infrastructure development on the island.

Through the evaluation of policy documents and targeted stakeholder interactions
within country, multiple visions for Saint Lucia’s future development were
identified (C). These visions were encoded into strategic approaches for future
infrastructure development that include three contrasting visions . This
includes a capacity expanson , system efficiency and system restructuring
strategies.

Further analysis was performed to identify potential specific strategic
alternatives (D), including investments and policies, that are either confirmed,
that are proposed in policy documents or that are potentials (as identified from
other countries or regions). This set of potential future alternatives was then
assigned to different strategies, in alignment with the identified visions of
development. Users of the model are encouraged to develop their own vision of
future infrastructure (e.g. environmentally-focused, low-cost, etc.) to better
understand trade-offs between strategies.

Based on data inputs in parts A-D, the model calculates a number of outputs
(E) on the performance of strategic infrastructure investments both sectorially
and cross-sectorally. In particular, each strategy is analyzed by assessing its
ability to meet future needs (for each of the given future scenarios of
demand).Key results and insights from the analysis emerged as follows: Energy –
of the scope of demand side and supply side interventions necessary to continue
to maintain its current electricity capacity margin – which is currently in
alignment with international best practice; Solid waste – of the scope and scale
of interventions necessary to address the forthcoming exceedance of capacity at
the island’s landfill site. Wastewater – of nature and scope of interventions
necessary to provide equitable services, nationally. Water – of the
interventions required to achieve reliability during dry season.

Finally, the portfolios of investments and policies were visualized and analyzed
as adaptable pathways (F). Adaptive pathways illustrate the sequencing of
infrastructure interventions contained in a set of strategy portfolios. This
section demonstrates a tool to guide infrastructure decision-making in Saint
Lucia in order to increase the robustness of its infrastructure choices to
future uncertainties and to optimize performance both at a sector level and
within the infrastructure system as a whole. Given resource limitations, this
adaptive perspective is particularly adept at incorporating flexibility and
built-in optionality to decision-making and encouraging a modular, small-scale
response to keep future options open. By laying out the sequencing of
interventions as a set of pathways, it is possible to identify ‘low-regret’
interventions that are common to multiple strategies, and identify potential
lock-in effects of large-scale infrastructure investments that may limit future
actions and responses. This approach can also incorporate lead-in times required
for each intervention. In a practical sense, this is necessary in order to
identify time frames in which investment funding must be raised, or conversely,
to pinpoint where short-term demand-side policies can be quickly implemented.

The degree to which NISMOD-LP can be successfully employed depends largely on
the scope and quality of data that is made available for the study. Therefore,
uncertainties inherent within input datasets will be carried through the
analysis and into any conclusions, recommendations and insights derived.
Additionally, the scope of the analysis (in terms of infrastructure sectors), is
constrained by data available and quality. Further details on NISMOD-LP can be
found in Thacker et al (2017).

### References

- Adshead, D., Fuldauer, L.I., Thacker, S., Román García, O., Vital, S., Felix,
  F., Roberts, C., Wells, H., Edwin, G., Providence, A. and Hall, J.W. 2020.
  Saint Lucia: National Infrastructure Assessment. United Nations Office for
  Project Services, Copenhagen, Denmark. Available at:
  https://content.unops.org/publications/Saint-Lucia-National-Infrastructure-Assessment.pdf
- Thacker, S., Hall, J.W., Russell, T., Pant, R., Leung, J., Koks, E. (2017)
  System-of-Systems Infrastructure Modelling to Support National Sustainable
  Development Outcomes. The 2017 International Symposium for Next Generation
  Infrastructure, London, UK.

## License

This work is licensed under a Creative Commons
Attribution-NonCommercial-ShareAlike 4.0 International License. Please see the
following website for complete license details.
http://creativecommons.org/licenses/by-nc-sa/4.0/legalcode

## Citation

This model may be cited as follows:

> Adshead D, Roman O, Thacker S, Felix F, Fuldauer Ll, Hickford AJ. 2018.
> Long-term strategic infrastructure planning model for Saint Lucia. University
> of Oxford and United Nations Office for Project Services, Oxford, UK.

## Information

The materials have been prepared mainly based on public information and
information provided by the UNOPS office in Saint Lucia. Whilst every care has
been taken to ensure the accuracy and completeness of the model, the reader must
recognize that errors are possible through no fault of UNOPS or the University
of Oxford and as such the parties give no express or implied representations or
warranty as to:

(i) the quality or fitness for any particular purpose of the model supplied or
of any design, workmanship, materials or parts used in connection therewith or
correspondence with regard to any description or sample; or

(ii) the accuracy, sufficiency or completeness of model provided. In particular,
there are hereby expressly excluded all conditions, warranties and other terms
which might otherwise be implied (whether by common law, by statute or
otherwise).

The University of Oxford and UNOPS, its employees, servants and agents shall
accept no liability for any damage caused directly or indirectly by the use of
any information contained herein and without prejudice to the generality of the
foregoing, by any inaccuracies, defects or omissions.
